@@ -6,9 +6,9 @@ from pathlib import Path
 import click
 from click import secho
 
-from indico_install.config import CLUSTER_NAME, yaml
+from indico_install.config import CLUSTER_NAME, yaml, D_PATH
 from indico_install.infra.input_utils import auth_with_gsutil
-from indico_install.utils import current_user, options_wrapper, run_cmd
+from indico_install.utils import current_user, run_cmd
 
 
 @click.command("cluster-info")
@@ -25,14 +25,13 @@ from indico_install.utils import current_user, options_wrapper, run_cmd
     show_default=False,
     help="Use sudo to run cluster dump (useful if running into permission issues)",
 )
-@options_wrapper()
-def cluster_info(ctx, *, upload, sudo, deployment_root, **kwargs):
+def cluster_info(ctx, *, upload, sudo):
     """
     Load and package all the information on the running cluster
     into a local TAR file.
     """
-    dumpdir = Path(deployment_root) / f"cluster_info_{time.strftime('%Y%m%d-%H%M%S')}"
-    secho(f"Pulling cluster info...", fg="blue")
+    dumpdir = D_PATH / f"cluster_info_{time.strftime('%Y%m%d-%H%M%S')}"
+    secho("Pulling cluster info...", fg="blue")
     sudo = "sudo " if sudo else ""
     run_cmd(
         f"""
@@ -69,7 +68,7 @@ def cluster_info(ctx, *, upload, sudo, deployment_root, **kwargs):
         return
 
     cluster_user = (
-        current_user(clean=True) if auth_with_gsutil(deployment_root) else CLUSTER_NAME
+        current_user(clean=True) if auth_with_gsutil() else CLUSTER_NAME
     )
     if not cluster_user:
         secho(
@@ -95,7 +94,7 @@ def cluster_info(ctx, *, upload, sudo, deployment_root, **kwargs):
         ),
         (
             "",
-            f"Unable to share cluster info with Indico. Please share the cluster info TAR manually",
+            "Unable to share cluster info with Indico. Please share the cluster info TAR manually",
             "red",
         ),
     )
