@@ -2,7 +2,7 @@ import os
 import uuid
 from click import secho, prompt, confirm
 
-from indico_install.config import ConfigsHolder
+from indico_install.config import ConfigsHolder, D_PATH
 from indico_install.utils import (
     base64file,
     find_values,
@@ -20,26 +20,33 @@ def configure_passwords(configs):
     configs.save()
 
 
-def configure_gcr_key(deployment_root):
+def configure_gcr_key():
     if run_cmd("kubectl get secrets | grep gcr-pull-secret", silent=True):
         return
 
-    key_file = find_gcs_key(deployment_root)
+    key_file = find_gcs_key()
     if not key_file:
         return
 
     secho("Generating gcr-pull-secret", fg="yellow")
     client_name = key_file[4:-5]
-    out = run_cmd(
-        (
-            "kubectl create secret docker-registry gcr-pull-secret "
-            "--docker-server=https://gcr.io --docker-username=_json_key "
-            f'--docker-password="$(cat {deployment_root}/gcr-{client_name}.json)" '
-            f'--docker-email="gcr-{client_name}@new-indico.iam.gserviceaccount.com"'
-        ),
-        silent=True,
+    secret_create = (
+        "kubectl create secret docker-registry gcr-pull-secret "
+        "--docker-server=https://gcr.io --docker-username=_json_key "
+        f'--docker-password="$(cat {D_PATH}/gcr-{client_name}.json)" '
+        f'--docker-email="gcr-{client_name}@new-indico.iam.gserviceaccount.com"'
+    )
+    default_out = run_cmd(secret_create + " --namespace default", silent=True)
+    ks_out = run_cmd(secret_create + " --namespace kube-system", silent=True)
+    secho(f"{default_out}\n", fg="green")
+    secho(f"{ks_out}\n", fg="green")
+    # allow secret reflection between namespaces
+    run_cmd(
+        "kubectl annotate secret gcr-pull-secret -n kube-system reflector.v1.k8s.emberstack.com/reflection-allowed='true'"
+    )
+    run_cmd(
+        "kubectl annotate secret gcr-pull-secret -n kube-system reflector.v1.k8s.emberstack.com/reflection-auto-enabled='true'"
     )
-    secho(f"{out}\n", fg="green")
 
 
 def get_tls(configs, redo=False):
